/* 
   FTP client implementation
   Copyright (C) 1998, Joe Orton <joe@orton.demon.co.uk>
                                                                     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* This module contains an FTP client implementation.
 * Simple to use:
 *   ftp_connect( "host.name.co.uk", 21 );
 *   ftp_login( "username", "password" );
 *   ftp_mkdir( "/asda/" );
 *   ftp_close( );
 * All commands return FTP_OK on success.
 */

#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>

/* Reply codes - these are returned by ftp_ functions */
#define FTP_OK 0
#define FTP_NEEDPASSWORD 1
#define FTP_PASSIVE 2
#define FTP_READY 3
#define FTP_FILEMORE 4
#define FTP_CLOSED 101
#define FTP_FILEBAD 102
#define FTP_DENIED 996
#define FTP_UNSUPPORTED 997
#define FTP_NOPASSIVE 998
#define FTP_ERROR 999

/* Connection functions */
int ftp_connect( char *hostname, int port );
int ftp_login( char *username, char *password );
int ftp_close( );

/* The commands available */
int ftp_put( char *localfile, char *remotefile );
int ftp_delete( char *filename );
int ftp_rmdir( char *dir );
int ftp_mkdir( char *dir );
int ftp_chdir( char *dir );
int ftp_godir( char * );
int ftp_chmod( char *filename, mode_t mode );
int ftp_move( char *from, char *to );

/*****
 * For internal use only
 *****/

int ftp_data_open( char * ); /* Opens the data connection */
int ftp_data_close( ); /* Closes the data connection */
int ftp_connect_pasv( void );
int ftp_read_pasv( char * ); /* Used by ftp_response to get the remote IP */

int ftp_response( char *, int ); /* Gets the return code */
int get_reply_code( char * ); /* Used by ftp_response to get the actual code */
void send_line( int, char * ); /* Sends a line to given socket */
int read_line( int, char *, int); /* Reads a line from given socket */
int send_file( char * ); /* Sends the given file down the data connection */

int ftp_exec( char * ); /* Executes given command, reads response */
int ftp_read( void );
